GenerateCellWidgets class
Specifies that a wrapper, exposing the properties as cells, should be generated for a widget.
NOTE: This annotation is currently only for internal use by the live_cells
package.
A widget wrapper class is generated for every specification in specs. This annotation can be applied to any element.
Constructors
-
GenerateCellWidgets(List<
WidgetSpec< specs)Object> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
specs
→ List<
WidgetSpec< Object> > -
Specifications of the widget wrapper classes to generated
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited